# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: department.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import task_pb2 as task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x65partment.proto\x12\ndepartment\x1a\ntask.proto\"l\n\nDepartment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x03 \x01(\t\x12\x0f\n\x07ti_task\x18\x04 \x01(\t\x12\x11\n\tmin_cores\x18\x05 \x01(\x02\x12\x12\n\nti_managed\x18\x06 \x01(\x08\"<\n\rDepartmentSeq\x12+\n\x0b\x64\x65partments\x18\x01 \x03(\x0b\x32\x16.department.Department\"&\n\x16\x44\x65ptAddDeptNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x19\n\x17\x44\x65ptAddDeptNameResponse\"a\n\x12\x44\x65ptAddTaskRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x0c\n\x04shot\x18\x02 \x01(\t\x12\x11\n\tmin_cores\x18\x03 \x01(\x02\"/\n\x13\x44\x65ptAddTaskResponse\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\"\xa7\x01\n\x13\x44\x65ptAddTasksRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x37\n\x04tmap\x18\x02 \x03(\x0b\x32).department.DeptAddTasksRequest.TmapEntry\x1a+\n\tTmapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"4\n\x14\x44\x65ptAddTasksResponse\x12\x1c\n\x05tasks\x18\x01 \x01(\x0b\x32\r.task.TaskSeq\"C\n\x15\x44\x65ptClearTasksRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\x18\n\x16\x44\x65ptClearTasksResponse\"M\n\x1f\x44\x65ptClearTaskAdjustmentsRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\"\n DeptClearTaskAdjustmentsResponse\"?\n\x11\x44\x65ptDeleteRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\x14\n\x12\x44\x65ptDeleteResponse\"I\n\x1b\x44\x65ptDisableTiManagedRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"\x1e\n\x1c\x44\x65ptDisableTiManagedResponse\"p\n\x1a\x44\x65ptEnableTiManagedRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x0f\n\x07ti_task\x18\x02 \x01(\t\x12\x15\n\rmanaged_cores\x18\x03 \x01(\x02\"\x1d\n\x1b\x44\x65ptEnableTiManagedResponse\"\x1f\n\x1d\x44\x65ptGetDepartmentNamesRequest\"/\n\x1e\x44\x65ptGetDepartmentNamesResponse\x12\r\n\x05names\x18\x01 \x03(\t\"A\n\x13\x44\x65ptGetTasksRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\"4\n\x14\x44\x65ptGetTasksResponse\x12\x1c\n\x05tasks\x18\x01 \x01(\x0b\x32\r.task.TaskSeq\"/\n\x1f\x44\x65ptRemoveDepartmentNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n DeptRemoveDepartmentNameResponse\"\xad\x01\n\x16\x44\x65ptReplaceTaskRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12:\n\x04tmap\x18\x02 \x03(\x0b\x32,.department.DeptReplaceTaskRequest.TmapEntry\x1a+\n\tTmapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"7\n\x17\x44\x65ptReplaceTaskResponse\x12\x1c\n\x05tasks\x18\x01 \x01(\x0b\x32\r.task.TaskSeq\"_\n\x1a\x44\x65ptSetManagedCoresRequest\x12*\n\ndepartment\x18\x01 \x01(\x0b\x32\x16.department.Department\x12\x15\n\rmanaged_cores\x18\x02 \x01(\x02\"\x1d\n\x1b\x44\x65ptSetManagedCoresResponse2\xd5\t\n\x13\x44\x65partmentInterface\x12\\\n\x11\x41\x64\x64\x44\x65partmentName\x12\".department.DeptAddDeptNameRequest\x1a#.department.DeptAddDeptNameResponse\x12J\n\x07\x41\x64\x64Task\x12\x1e.department.DeptAddTaskRequest\x1a\x1f.department.DeptAddTaskResponse\x12M\n\x08\x41\x64\x64Tasks\x12\x1f.department.DeptAddTasksRequest\x1a .department.DeptAddTasksResponse\x12S\n\nClearTasks\x12!.department.DeptClearTasksRequest\x1a\".department.DeptClearTasksResponse\x12q\n\x14\x43learTaskAdjustments\x12+.department.DeptClearTaskAdjustmentsRequest\x1a,.department.DeptClearTaskAdjustmentsResponse\x12G\n\x06\x44\x65lete\x12\x1d.department.DeptDeleteRequest\x1a\x1e.department.DeptDeleteResponse\x12\x65\n\x10\x44isableTiManaged\x12\'.department.DeptDisableTiManagedRequest\x1a(.department.DeptDisableTiManagedResponse\x12\x62\n\x0f\x45nableTiManaged\x12&.department.DeptEnableTiManagedRequest\x1a\'.department.DeptEnableTiManagedResponse\x12k\n\x12GetDepartmentNames\x12).department.DeptGetDepartmentNamesRequest\x1a*.department.DeptGetDepartmentNamesResponse\x12M\n\x08GetTasks\x12\x1f.department.DeptGetTasksRequest\x1a .department.DeptGetTasksResponse\x12q\n\x14RemoveDepartmentName\x12+.department.DeptRemoveDepartmentNameRequest\x1a,.department.DeptRemoveDepartmentNameResponse\x12W\n\x0cReplaceTasks\x12\".department.DeptReplaceTaskRequest\x1a#.department.DeptReplaceTaskResponse\x12\x61\n\x0eSetMangedCores\x12&.department.DeptSetManagedCoresRequest\x1a\'.department.DeptSetManagedCoresResponseB@\n$com.imageworks.spcue.grpc.departmentP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'department_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.imageworks.spcue.grpc.departmentP\001Z\026opencue_gateway/gen/go'
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._options = None
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._serialized_options = b'8\001'
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._options = None
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._serialized_options = b'8\001'
  _globals['_DEPARTMENT']._serialized_start=44
  _globals['_DEPARTMENT']._serialized_end=152
  _globals['_DEPARTMENTSEQ']._serialized_start=154
  _globals['_DEPARTMENTSEQ']._serialized_end=214
  _globals['_DEPTADDDEPTNAMEREQUEST']._serialized_start=216
  _globals['_DEPTADDDEPTNAMEREQUEST']._serialized_end=254
  _globals['_DEPTADDDEPTNAMERESPONSE']._serialized_start=256
  _globals['_DEPTADDDEPTNAMERESPONSE']._serialized_end=281
  _globals['_DEPTADDTASKREQUEST']._serialized_start=283
  _globals['_DEPTADDTASKREQUEST']._serialized_end=380
  _globals['_DEPTADDTASKRESPONSE']._serialized_start=382
  _globals['_DEPTADDTASKRESPONSE']._serialized_end=429
  _globals['_DEPTADDTASKSREQUEST']._serialized_start=432
  _globals['_DEPTADDTASKSREQUEST']._serialized_end=599
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._serialized_start=556
  _globals['_DEPTADDTASKSREQUEST_TMAPENTRY']._serialized_end=599
  _globals['_DEPTADDTASKSRESPONSE']._serialized_start=601
  _globals['_DEPTADDTASKSRESPONSE']._serialized_end=653
  _globals['_DEPTCLEARTASKSREQUEST']._serialized_start=655
  _globals['_DEPTCLEARTASKSREQUEST']._serialized_end=722
  _globals['_DEPTCLEARTASKSRESPONSE']._serialized_start=724
  _globals['_DEPTCLEARTASKSRESPONSE']._serialized_end=748
  _globals['_DEPTCLEARTASKADJUSTMENTSREQUEST']._serialized_start=750
  _globals['_DEPTCLEARTASKADJUSTMENTSREQUEST']._serialized_end=827
  _globals['_DEPTCLEARTASKADJUSTMENTSRESPONSE']._serialized_start=829
  _globals['_DEPTCLEARTASKADJUSTMENTSRESPONSE']._serialized_end=863
  _globals['_DEPTDELETEREQUEST']._serialized_start=865
  _globals['_DEPTDELETEREQUEST']._serialized_end=928
  _globals['_DEPTDELETERESPONSE']._serialized_start=930
  _globals['_DEPTDELETERESPONSE']._serialized_end=950
  _globals['_DEPTDISABLETIMANAGEDREQUEST']._serialized_start=952
  _globals['_DEPTDISABLETIMANAGEDREQUEST']._serialized_end=1025
  _globals['_DEPTDISABLETIMANAGEDRESPONSE']._serialized_start=1027
  _globals['_DEPTDISABLETIMANAGEDRESPONSE']._serialized_end=1057
  _globals['_DEPTENABLETIMANAGEDREQUEST']._serialized_start=1059
  _globals['_DEPTENABLETIMANAGEDREQUEST']._serialized_end=1171
  _globals['_DEPTENABLETIMANAGEDRESPONSE']._serialized_start=1173
  _globals['_DEPTENABLETIMANAGEDRESPONSE']._serialized_end=1202
  _globals['_DEPTGETDEPARTMENTNAMESREQUEST']._serialized_start=1204
  _globals['_DEPTGETDEPARTMENTNAMESREQUEST']._serialized_end=1235
  _globals['_DEPTGETDEPARTMENTNAMESRESPONSE']._serialized_start=1237
  _globals['_DEPTGETDEPARTMENTNAMESRESPONSE']._serialized_end=1284
  _globals['_DEPTGETTASKSREQUEST']._serialized_start=1286
  _globals['_DEPTGETTASKSREQUEST']._serialized_end=1351
  _globals['_DEPTGETTASKSRESPONSE']._serialized_start=1353
  _globals['_DEPTGETTASKSRESPONSE']._serialized_end=1405
  _globals['_DEPTREMOVEDEPARTMENTNAMEREQUEST']._serialized_start=1407
  _globals['_DEPTREMOVEDEPARTMENTNAMEREQUEST']._serialized_end=1454
  _globals['_DEPTREMOVEDEPARTMENTNAMERESPONSE']._serialized_start=1456
  _globals['_DEPTREMOVEDEPARTMENTNAMERESPONSE']._serialized_end=1490
  _globals['_DEPTREPLACETASKREQUEST']._serialized_start=1493
  _globals['_DEPTREPLACETASKREQUEST']._serialized_end=1666
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._serialized_start=556
  _globals['_DEPTREPLACETASKREQUEST_TMAPENTRY']._serialized_end=599
  _globals['_DEPTREPLACETASKRESPONSE']._serialized_start=1668
  _globals['_DEPTREPLACETASKRESPONSE']._serialized_end=1723
  _globals['_DEPTSETMANAGEDCORESREQUEST']._serialized_start=1725
  _globals['_DEPTSETMANAGEDCORESREQUEST']._serialized_end=1820
  _globals['_DEPTSETMANAGEDCORESRESPONSE']._serialized_start=1822
  _globals['_DEPTSETMANAGEDCORESRESPONSE']._serialized_end=1851
  _globals['_DEPARTMENTINTERFACE']._serialized_start=1854
  _globals['_DEPARTMENTINTERFACE']._serialized_end=3091
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: filter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import job_pb2 as job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66ilter.proto\x12\x06\x66ilter\x1a\tjob.proto\"\xd1\x01\n\x06\x41\x63tion\x12\n\n\x02id\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.filter.ActionType\x12+\n\nvalue_type\x18\x03 \x01(\x0e\x32\x17.filter.ActionValueType\x12\x13\n\x0bgroup_value\x18\x04 \x01(\t\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\x12\x15\n\rinteger_value\x18\x06 \x01(\x05\x12\x13\n\x0b\x66loat_value\x18\x07 \x01(\x02\x12\x15\n\rboolean_value\x18\x08 \x01(\x08\",\n\tActionSeq\x12\x1f\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x0e.filter.Action\"d\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.filter.FilterType\x12\r\n\x05order\x18\x04 \x01(\x02\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\",\n\tFilterSeq\x12\x1f\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x0e.filter.Filter\"l\n\x07Matcher\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\x07subject\x18\x02 \x01(\x0e\x32\x14.filter.MatchSubject\x12\x1f\n\x04type\x18\x03 \x01(\x0e\x32\x11.filter.MatchType\x12\r\n\x05input\x18\x04 \x01(\t\"/\n\nMatcherSeq\x12!\n\x08matchers\x18\x01 \x03(\x0b\x32\x0f.filter.Matcher\"5\n\x13\x41\x63tionCommitRequest\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"\x16\n\x14\x41\x63tionCommitResponse\"5\n\x13\x41\x63tionDeleteRequest\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"\x16\n\x14\x41\x63tionDeleteResponse\">\n\x1c\x41\x63tionGetParentFilterRequest\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"?\n\x1d\x41\x63tionGetParentFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"Y\n\x19\x46ilterCreateActionRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x1c\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x0e.filter.Action\"<\n\x1a\x46ilterCreateActionResponse\x12\x1e\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x0e.filter.Action\"[\n\x1a\x46ilterCreateMatcherRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x1d\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x0f.filter.Matcher\"?\n\x1b\x46ilterCreateMatcherResponse\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"5\n\x13\x46ilterDeleteRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x16\n\x14\x46ilterDeleteResponse\"5\n\x17\x46ilterFindFilterRequest\x12\x0c\n\x04show\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x18\x46ilterFindFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"9\n\x17\x46ilterGetActionsRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\">\n\x18\x46ilterGetActionsResponse\x12\"\n\x07\x61\x63tions\x18\x01 \x01(\x0b\x32\x11.filter.ActionSeq\":\n\x18\x46ilterGetMatchersRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"A\n\x19\x46ilterGetMatchersResponse\x12$\n\x08matchers\x18\x01 \x01(\x0b\x32\x12.filter.MatcherSeq\"9\n\x17\x46ilterLowerOrderRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x1a\n\x18\x46ilterLowerOrderResponse\"9\n\x17\x46ilterOrderFirstRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x1a\n\x18\x46ilterOrderFirstResponse\"8\n\x16\x46ilterOrderLastRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x19\n\x17\x46ilterOrderLastResponse\"9\n\x17\x46ilterRaiseOrderRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\"\x1a\n\x18\x46ilterRaiseOrderResponse\"Z\n\x1d\x46ilterRunFilterOnGroupRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x19\n\x05group\x18\x02 \x01(\x0b\x32\n.job.Group\" \n\x1e\x46ilterRunFilterOnGroupResponse\"Y\n\x1c\x46ilterRunFilterOnJobsRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x19\n\x04jobs\x18\x02 \x01(\x0b\x32\x0b.job.JobSeq\"\x1f\n\x1d\x46ilterRunFilterOnJobsResponse\"J\n\x17\x46ilterSetEnabledRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\x1a\n\x18\x46ilterSetEnabledResponse\"D\n\x14\x46ilterSetNameRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x46ilterSetNameResponse\"F\n\x15\x46ilterSetOrderRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12\r\n\x05order\x18\x02 \x01(\x05\"\x18\n\x16\x46ilterSetOrderResponse\"X\n\x14\x46ilterSetTypeRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter\x12 \n\x04type\x18\x02 \x01(\x0e\x32\x12.filter.FilterType\"\x17\n\x15\x46ilterSetTypeResponse\"8\n\x14MatcherCommitRequest\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"\x17\n\x15MatcherCommitResponse\"8\n\x14MatcherDeleteRequest\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"\x17\n\x15MatcherDeleteResponse\"A\n\x1dMatcherGetParentFilterRequest\x12 \n\x07matcher\x18\x01 \x01(\x0b\x32\x0f.filter.Matcher\"@\n\x1eMatcherGetParentFilterResponse\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.filter.Filter*\xd1\x02\n\nActionType\x12\x15\n\x11MOVE_JOB_TO_GROUP\x10\x00\x12\r\n\tPAUSE_JOB\x10\x01\x12\x15\n\x11SET_JOB_MIN_CORES\x10\x02\x12\x15\n\x11SET_JOB_MAX_CORES\x10\x03\x12\x13\n\x0fSTOP_PROCESSING\x10\x04\x12\x14\n\x10SET_JOB_PRIORITY\x10\x05\x12\x1d\n\x19SET_ALL_RENDER_LAYER_TAGS\x10\x06\x12\x1f\n\x1bSET_ALL_RENDER_LAYER_MEMORY\x10\x07\x12\"\n\x1aSET_ALL_RENDER_LAYER_CORES\x10\x08\x1a\x02\x08\x01\x12\x18\n\x14SET_MEMORY_OPTIMIZER\x10\t\x12\"\n\x1eSET_ALL_RENDER_LAYER_MIN_CORES\x10\n\x12\"\n\x1eSET_ALL_RENDER_LAYER_MAX_CORES\x10\x0b*u\n\x0f\x41\x63tionValueType\x12\x0e\n\nGROUP_TYPE\x10\x00\x12\x0f\n\x0bSTRING_TYPE\x10\x01\x12\x10\n\x0cINTEGER_TYPE\x10\x02\x12\x0e\n\nFLOAT_TYPE\x10\x03\x12\x10\n\x0c\x42OOLEAN_TYPE\x10\x04\x12\r\n\tNONE_TYPE\x10\x05**\n\nFilterType\x12\r\n\tMATCH_ANY\x10\x00\x12\r\n\tMATCH_ALL\x10\x01*x\n\x0cMatchSubject\x12\x0c\n\x08JOB_NAME\x10\x00\x12\x08\n\x04SHOW\x10\x01\x12\x08\n\x04SHOT\x10\x02\x12\x08\n\x04USER\x10\x03\x12\x10\n\x0cSERVICE_NAME\x10\x04\x12\x0c\n\x08PRIORITY\x10\x05\x12\x0c\n\x08\x46\x41\x43ILITY\x10\x06\x12\x0e\n\nLAYER_NAME\x10\x07*n\n\tMatchType\x12\x0c\n\x08\x43ONTAINS\x10\x00\x12\x14\n\x10\x44OES_NOT_CONTAIN\x10\x01\x12\x06\n\x02IS\x10\x02\x12\n\n\x06IS_NOT\x10\x03\x12\t\n\x05REGEX\x10\x04\x12\x0f\n\x0b\x42\x45GINS_WITH\x10\x05\x12\r\n\tENDS_WITH\x10\x06\x32\xfb\x01\n\x0f\x41\x63tionInterface\x12\x43\n\x06\x43ommit\x12\x1b.filter.ActionCommitRequest\x1a\x1c.filter.ActionCommitResponse\x12\x43\n\x06\x44\x65lete\x12\x1b.filter.ActionDeleteRequest\x1a\x1c.filter.ActionDeleteResponse\x12^\n\x0fGetParentFilter\x12$.filter.ActionGetParentFilterRequest\x1a%.filter.ActionGetParentFilterResponse2\xad\n\n\x0f\x46ilterInterface\x12U\n\x0c\x43reateAction\x12!.filter.FilterCreateActionRequest\x1a\".filter.FilterCreateActionResponse\x12X\n\rCreateMatcher\x12\".filter.FilterCreateMatcherRequest\x1a#.filter.FilterCreateMatcherResponse\x12\x43\n\x06\x44\x65lete\x12\x1b.filter.FilterDeleteRequest\x1a\x1c.filter.FilterDeleteResponse\x12O\n\nFindFilter\x12\x1f.filter.FilterFindFilterRequest\x1a .filter.FilterFindFilterResponse\x12O\n\nGetActions\x12\x1f.filter.FilterGetActionsRequest\x1a .filter.FilterGetActionsResponse\x12R\n\x0bGetMatchers\x12 .filter.FilterGetMatchersRequest\x1a!.filter.FilterGetMatchersResponse\x12O\n\nLowerOrder\x12\x1f.filter.FilterLowerOrderRequest\x1a .filter.FilterLowerOrderResponse\x12O\n\nOrderFirst\x12\x1f.filter.FilterOrderFirstRequest\x1a .filter.FilterOrderFirstResponse\x12L\n\tOrderLast\x12\x1e.filter.FilterOrderLastRequest\x1a\x1f.filter.FilterOrderLastResponse\x12O\n\nRaiseOrder\x12\x1f.filter.FilterRaiseOrderRequest\x1a .filter.FilterRaiseOrderResponse\x12\x61\n\x10RunFilterOnGroup\x12%.filter.FilterRunFilterOnGroupRequest\x1a&.filter.FilterRunFilterOnGroupResponse\x12^\n\x0fRunFilterOnJobs\x12$.filter.FilterRunFilterOnJobsRequest\x1a%.filter.FilterRunFilterOnJobsResponse\x12O\n\nSetEnabled\x12\x1f.filter.FilterSetEnabledRequest\x1a .filter.FilterSetEnabledResponse\x12\x46\n\x07SetName\x12\x1c.filter.FilterSetNameRequest\x1a\x1d.filter.FilterSetNameResponse\x12I\n\x08SetOrder\x12\x1d.filter.FilterSetOrderRequest\x1a\x1e.filter.FilterSetOrderResponse\x12\x46\n\x07SetType\x12\x1c.filter.FilterSetTypeRequest\x1a\x1d.filter.FilterSetTypeResponse2\x82\x02\n\x10MatcherInterface\x12\x45\n\x06\x43ommit\x12\x1c.filter.MatcherCommitRequest\x1a\x1d.filter.MatcherCommitResponse\x12\x45\n\x06\x44\x65lete\x12\x1c.filter.MatcherDeleteRequest\x1a\x1d.filter.MatcherDeleteResponse\x12`\n\x0fGetParentFilter\x12%.filter.MatcherGetParentFilterRequest\x1a&.filter.MatcherGetParentFilterResponseB<\n com.imageworks.spcue.grpc.filterP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.imageworks.spcue.grpc.filterP\001Z\026opencue_gateway/gen/go'
  _globals['_ACTIONTYPE'].values_by_name["SET_ALL_RENDER_LAYER_CORES"]._options = None
  _globals['_ACTIONTYPE'].values_by_name["SET_ALL_RENDER_LAYER_CORES"]._serialized_options = b'\010\001'
  _globals['_ACTIONTYPE']._serialized_start=2950
  _globals['_ACTIONTYPE']._serialized_end=3287
  _globals['_ACTIONVALUETYPE']._serialized_start=3289
  _globals['_ACTIONVALUETYPE']._serialized_end=3406
  _globals['_FILTERTYPE']._serialized_start=3408
  _globals['_FILTERTYPE']._serialized_end=3450
  _globals['_MATCHSUBJECT']._serialized_start=3452
  _globals['_MATCHSUBJECT']._serialized_end=3572
  _globals['_MATCHTYPE']._serialized_start=3574
  _globals['_MATCHTYPE']._serialized_end=3684
  _globals['_ACTION']._serialized_start=36
  _globals['_ACTION']._serialized_end=245
  _globals['_ACTIONSEQ']._serialized_start=247
  _globals['_ACTIONSEQ']._serialized_end=291
  _globals['_FILTER']._serialized_start=293
  _globals['_FILTER']._serialized_end=393
  _globals['_FILTERSEQ']._serialized_start=395
  _globals['_FILTERSEQ']._serialized_end=439
  _globals['_MATCHER']._serialized_start=441
  _globals['_MATCHER']._serialized_end=549
  _globals['_MATCHERSEQ']._serialized_start=551
  _globals['_MATCHERSEQ']._serialized_end=598
  _globals['_ACTIONCOMMITREQUEST']._serialized_start=600
  _globals['_ACTIONCOMMITREQUEST']._serialized_end=653
  _globals['_ACTIONCOMMITRESPONSE']._serialized_start=655
  _globals['_ACTIONCOMMITRESPONSE']._serialized_end=677
  _globals['_ACTIONDELETEREQUEST']._serialized_start=679
  _globals['_ACTIONDELETEREQUEST']._serialized_end=732
  _globals['_ACTIONDELETERESPONSE']._serialized_start=734
  _globals['_ACTIONDELETERESPONSE']._serialized_end=756
  _globals['_ACTIONGETPARENTFILTERREQUEST']._serialized_start=758
  _globals['_ACTIONGETPARENTFILTERREQUEST']._serialized_end=820
  _globals['_ACTIONGETPARENTFILTERRESPONSE']._serialized_start=822
  _globals['_ACTIONGETPARENTFILTERRESPONSE']._serialized_end=885
  _globals['_FILTERCREATEACTIONREQUEST']._serialized_start=887
  _globals['_FILTERCREATEACTIONREQUEST']._serialized_end=976
  _globals['_FILTERCREATEACTIONRESPONSE']._serialized_start=978
  _globals['_FILTERCREATEACTIONRESPONSE']._serialized_end=1038
  _globals['_FILTERCREATEMATCHERREQUEST']._serialized_start=1040
  _globals['_FILTERCREATEMATCHERREQUEST']._serialized_end=1131
  _globals['_FILTERCREATEMATCHERRESPONSE']._serialized_start=1133
  _globals['_FILTERCREATEMATCHERRESPONSE']._serialized_end=1196
  _globals['_FILTERDELETEREQUEST']._serialized_start=1198
  _globals['_FILTERDELETEREQUEST']._serialized_end=1251
  _globals['_FILTERDELETERESPONSE']._serialized_start=1253
  _globals['_FILTERDELETERESPONSE']._serialized_end=1275
  _globals['_FILTERFINDFILTERREQUEST']._serialized_start=1277
  _globals['_FILTERFINDFILTERREQUEST']._serialized_end=1330
  _globals['_FILTERFINDFILTERRESPONSE']._serialized_start=1332
  _globals['_FILTERFINDFILTERRESPONSE']._serialized_end=1390
  _globals['_FILTERGETACTIONSREQUEST']._serialized_start=1392
  _globals['_FILTERGETACTIONSREQUEST']._serialized_end=1449
  _globals['_FILTERGETACTIONSRESPONSE']._serialized_start=1451
  _globals['_FILTERGETACTIONSRESPONSE']._serialized_end=1513
  _globals['_FILTERGETMATCHERSREQUEST']._serialized_start=1515
  _globals['_FILTERGETMATCHERSREQUEST']._serialized_end=1573
  _globals['_FILTERGETMATCHERSRESPONSE']._serialized_start=1575
  _globals['_FILTERGETMATCHERSRESPONSE']._serialized_end=1640
  _globals['_FILTERLOWERORDERREQUEST']._serialized_start=1642
  _globals['_FILTERLOWERORDERREQUEST']._serialized_end=1699
  _globals['_FILTERLOWERORDERRESPONSE']._serialized_start=1701
  _globals['_FILTERLOWERORDERRESPONSE']._serialized_end=1727
  _globals['_FILTERORDERFIRSTREQUEST']._serialized_start=1729
  _globals['_FILTERORDERFIRSTREQUEST']._serialized_end=1786
  _globals['_FILTERORDERFIRSTRESPONSE']._serialized_start=1788
  _globals['_FILTERORDERFIRSTRESPONSE']._serialized_end=1814
  _globals['_FILTERORDERLASTREQUEST']._serialized_start=1816
  _globals['_FILTERORDERLASTREQUEST']._serialized_end=1872
  _globals['_FILTERORDERLASTRESPONSE']._serialized_start=1874
  _globals['_FILTERORDERLASTRESPONSE']._serialized_end=1899
  _globals['_FILTERRAISEORDERREQUEST']._serialized_start=1901
  _globals['_FILTERRAISEORDERREQUEST']._serialized_end=1958
  _globals['_FILTERRAISEORDERRESPONSE']._serialized_start=1960
  _globals['_FILTERRAISEORDERRESPONSE']._serialized_end=1986
  _globals['_FILTERRUNFILTERONGROUPREQUEST']._serialized_start=1988
  _globals['_FILTERRUNFILTERONGROUPREQUEST']._serialized_end=2078
  _globals['_FILTERRUNFILTERONGROUPRESPONSE']._serialized_start=2080
  _globals['_FILTERRUNFILTERONGROUPRESPONSE']._serialized_end=2112
  _globals['_FILTERRUNFILTERONJOBSREQUEST']._serialized_start=2114
  _globals['_FILTERRUNFILTERONJOBSREQUEST']._serialized_end=2203
  _globals['_FILTERRUNFILTERONJOBSRESPONSE']._serialized_start=2205
  _globals['_FILTERRUNFILTERONJOBSRESPONSE']._serialized_end=2236
  _globals['_FILTERSETENABLEDREQUEST']._serialized_start=2238
  _globals['_FILTERSETENABLEDREQUEST']._serialized_end=2312
  _globals['_FILTERSETENABLEDRESPONSE']._serialized_start=2314
  _globals['_FILTERSETENABLEDRESPONSE']._serialized_end=2340
  _globals['_FILTERSETNAMEREQUEST']._serialized_start=2342
  _globals['_FILTERSETNAMEREQUEST']._serialized_end=2410
  _globals['_FILTERSETNAMERESPONSE']._serialized_start=2412
  _globals['_FILTERSETNAMERESPONSE']._serialized_end=2435
  _globals['_FILTERSETORDERREQUEST']._serialized_start=2437
  _globals['_FILTERSETORDERREQUEST']._serialized_end=2507
  _globals['_FILTERSETORDERRESPONSE']._serialized_start=2509
  _globals['_FILTERSETORDERRESPONSE']._serialized_end=2533
  _globals['_FILTERSETTYPEREQUEST']._serialized_start=2535
  _globals['_FILTERSETTYPEREQUEST']._serialized_end=2623
  _globals['_FILTERSETTYPERESPONSE']._serialized_start=2625
  _globals['_FILTERSETTYPERESPONSE']._serialized_end=2648
  _globals['_MATCHERCOMMITREQUEST']._serialized_start=2650
  _globals['_MATCHERCOMMITREQUEST']._serialized_end=2706
  _globals['_MATCHERCOMMITRESPONSE']._serialized_start=2708
  _globals['_MATCHERCOMMITRESPONSE']._serialized_end=2731
  _globals['_MATCHERDELETEREQUEST']._serialized_start=2733
  _globals['_MATCHERDELETEREQUEST']._serialized_end=2789
  _globals['_MATCHERDELETERESPONSE']._serialized_start=2791
  _globals['_MATCHERDELETERESPONSE']._serialized_end=2814
  _globals['_MATCHERGETPARENTFILTERREQUEST']._serialized_start=2816
  _globals['_MATCHERGETPARENTFILTERREQUEST']._serialized_end=2881
  _globals['_MATCHERGETPARENTFILTERRESPONSE']._serialized_start=2883
  _globals['_MATCHERGETPARENTFILTERRESPONSE']._serialized_end=2947
  _globals['_ACTIONINTERFACE']._serialized_start=3687
  _globals['_ACTIONINTERFACE']._serialized_end=3938
  _globals['_FILTERINTERFACE']._serialized_start=3941
  _globals['_FILTERINTERFACE']._serialized_end=5266
  _globals['_MATCHERINTERFACE']._serialized_start=5269
  _globals['_MATCHERINTERFACE']._serialized_end=5527
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import host_pb2 as host__pb2


class DeedInterfaceStub(object):
    """-------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Delete = channel.unary_unary(
                '/host.DeedInterface/Delete',
                request_serializer=host__pb2.DeedDeleteRequest.SerializeToString,
                response_deserializer=host__pb2.DeedDeleteResponse.FromString,
                )
        self.GetHost = channel.unary_unary(
                '/host.DeedInterface/GetHost',
                request_serializer=host__pb2.DeedGetHostRequest.SerializeToString,
                response_deserializer=host__pb2.DeedGetHostResponse.FromString,
                )
        self.GetOwner = channel.unary_unary(
                '/host.DeedInterface/GetOwner',
                request_serializer=host__pb2.DeedGetOwnerRequest.SerializeToString,
                response_deserializer=host__pb2.DeedGetOwnerResponse.FromString,
                )


class DeedInterfaceServicer(object):
    """-------- Services --------]

    """

    def Delete(self, request, context):
        """Remove the deed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHost(self, request, context):
        """Returns the full host for these settings.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOwner(self, request, context):
        """Returns the owner for these settings.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeedInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=host__pb2.DeedDeleteRequest.FromString,
                    response_serializer=host__pb2.DeedDeleteResponse.SerializeToString,
            ),
            'GetHost': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHost,
                    request_deserializer=host__pb2.DeedGetHostRequest.FromString,
                    response_serializer=host__pb2.DeedGetHostResponse.SerializeToString,
            ),
            'GetOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOwner,
                    request_deserializer=host__pb2.DeedGetOwnerRequest.FromString,
                    response_serializer=host__pb2.DeedGetOwnerResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'host.DeedInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeedInterface(object):
    """-------- Services --------]

    """

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.DeedInterface/Delete',
            host__pb2.DeedDeleteRequest.SerializeToString,
            host__pb2.DeedDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.DeedInterface/GetHost',
            host__pb2.DeedGetHostRequest.SerializeToString,
            host__pb2.DeedGetHostResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.DeedInterface/GetOwner',
            host__pb2.DeedGetOwnerRequest.SerializeToString,
            host__pb2.DeedGetOwnerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class HostInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddComment = channel.unary_unary(
                '/host.HostInterface/AddComment',
                request_serializer=host__pb2.HostAddCommentRequest.SerializeToString,
                response_deserializer=host__pb2.HostAddCommentResponse.FromString,
                )
        self.AddTags = channel.unary_unary(
                '/host.HostInterface/AddTags',
                request_serializer=host__pb2.HostAddTagsRequest.SerializeToString,
                response_deserializer=host__pb2.HostAddTagsResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/host.HostInterface/Delete',
                request_serializer=host__pb2.HostDeleteRequest.SerializeToString,
                response_deserializer=host__pb2.HostDeleteResponse.FromString,
                )
        self.FindHost = channel.unary_unary(
                '/host.HostInterface/FindHost',
                request_serializer=host__pb2.HostFindHostRequest.SerializeToString,
                response_deserializer=host__pb2.HostFindHostResponse.FromString,
                )
        self.GetComments = channel.unary_unary(
                '/host.HostInterface/GetComments',
                request_serializer=host__pb2.HostGetCommentsRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetCommentsResponse.FromString,
                )
        self.GetDeed = channel.unary_unary(
                '/host.HostInterface/GetDeed',
                request_serializer=host__pb2.HostGetDeedRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetDeedResponse.FromString,
                )
        self.GetHost = channel.unary_unary(
                '/host.HostInterface/GetHost',
                request_serializer=host__pb2.HostGetHostRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetHostResponse.FromString,
                )
        self.GetHosts = channel.unary_unary(
                '/host.HostInterface/GetHosts',
                request_serializer=host__pb2.HostGetHostsRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetHostsResponse.FromString,
                )
        self.GetHostWhiteboard = channel.unary_unary(
                '/host.HostInterface/GetHostWhiteboard',
                request_serializer=host__pb2.HostGetHostWhiteboardRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetHostWhiteboardResponse.FromString,
                )
        self.GetOwner = channel.unary_unary(
                '/host.HostInterface/GetOwner',
                request_serializer=host__pb2.HostGetOwnerRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetOwnerResponse.FromString,
                )
        self.GetProcs = channel.unary_unary(
                '/host.HostInterface/GetProcs',
                request_serializer=host__pb2.HostGetProcsRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetProcsResponse.FromString,
                )
        self.GetRenderPartitions = channel.unary_unary(
                '/host.HostInterface/GetRenderPartitions',
                request_serializer=host__pb2.HostGetRenderPartitionsRequest.SerializeToString,
                response_deserializer=host__pb2.HostGetRenderPartitionsResponse.FromString,
                )
        self.Lock = channel.unary_unary(
                '/host.HostInterface/Lock',
                request_serializer=host__pb2.HostLockRequest.SerializeToString,
                response_deserializer=host__pb2.HostLockResponse.FromString,
                )
        self.Reboot = channel.unary_unary(
                '/host.HostInterface/Reboot',
                request_serializer=host__pb2.HostRebootRequest.SerializeToString,
                response_deserializer=host__pb2.HostRebootResponse.FromString,
                )
        self.RebootWhenIdle = channel.unary_unary(
                '/host.HostInterface/RebootWhenIdle',
                request_serializer=host__pb2.HostRebootWhenIdleRequest.SerializeToString,
                response_deserializer=host__pb2.HostRebootWhenIdleResponse.FromString,
                )
        self.RedirectToJob = channel.unary_unary(
                '/host.HostInterface/RedirectToJob',
                request_serializer=host__pb2.HostRedirectToJobRequest.SerializeToString,
                response_deserializer=host__pb2.HostRedirectToJobResponse.FromString,
                )
        self.RemoveTags = channel.unary_unary(
                '/host.HostInterface/RemoveTags',
                request_serializer=host__pb2.HostRemoveTagsRequest.SerializeToString,
                response_deserializer=host__pb2.HostRemoveTagsResponse.FromString,
                )
        self.RenameTag = channel.unary_unary(
                '/host.HostInterface/RenameTag',
                request_serializer=host__pb2.HostRenameTagRequest.SerializeToString,
                response_deserializer=host__pb2.HostRenameTagResponse.FromString,
                )
        self.SetAllocation = channel.unary_unary(
                '/host.HostInterface/SetAllocation',
                request_serializer=host__pb2.HostSetAllocationRequest.SerializeToString,
                response_deserializer=host__pb2.HostSetAllocationResponse.FromString,
                )
        self.SetHardwareState = channel.unary_unary(
                '/host.HostInterface/SetHardwareState',
                request_serializer=host__pb2.HostSetHardwareStateRequest.SerializeToString,
                response_deserializer=host__pb2.HostSetHardwareStateResponse.FromString,
                )
        self.SetOs = channel.unary_unary(
                '/host.HostInterface/SetOs',
                request_serializer=host__pb2.HostSetOsRequest.SerializeToString,
                response_deserializer=host__pb2.HostSetOsResponse.FromString,
                )
        self.SetThreadMode = channel.unary_unary(
                '/host.HostInterface/SetThreadMode',
                request_serializer=host__pb2.HostSetThreadModeRequest.SerializeToString,
                response_deserializer=host__pb2.HostSetThreadModeResponse.FromString,
                )
        self.Unlock = channel.unary_unary(
                '/host.HostInterface/Unlock',
                request_serializer=host__pb2.HostUnlockRequest.SerializeToString,
                response_deserializer=host__pb2.HostUnlockResponse.FromString,
                )


class HostInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddComment(self, request, context):
        """Add a comment on this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTags(self, request, context):
        """Set a tag on this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindHost(self, request, context):
        """Find a host by its name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComments(self, request, context):
        """Get the comments for this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeed(self, request, context):
        """Return the deed for this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHost(self, request, context):
        """Return a host by its id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHosts(self, request, context):
        """Search for a number of hosts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHostWhiteboard(self, request, context):
        """Return the host whiteboard
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOwner(self, request, context):
        """Get the owner settings of this particular host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProcs(self, request, context):
        """Returns the list of proc resources allocated from this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRenderPartitions(self, request, context):
        """Return any render partitions that are setup on this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Lock(self, request, context):
        """Locks the host.  Its possible we'll need to pass in a show name here in the future
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reboot(self, request, context):
        """Issues an immediate reboot.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RebootWhenIdle(self, request, context):
        """Sets the reboot when idle state, nothing has to be locked to set this. When the host pings in idle a reboot
        command is sent to the host and the host will be put into the Rebooting state.  If any locks are set they will
        be removed upon reboot.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RedirectToJob(self, request, context):
        """Redirect the given procs to the specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveTags(self, request, context):
        """Remove a tag from this host.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenameTag(self, request, context):
        """Rename tag.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAllocation(self, request, context):
        """Assign a host to an allocation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetHardwareState(self, request, context):
        """Manually set the hardware state for the host.  The hardware state may be changed automatically if the host pings
        in.  If the hardware state is set to "Reimage", the state will not automatically change with a host ping, and
        must be manually set back to Up.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOs(self, request, context):
        """Set the name of the host operating system.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetThreadMode(self, request, context):
        """Changes the host's [ThreadMode]
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unlock(self, request, context):
        """Unlocks the host for booking if the proc is in the Locked state. You cannot unlock a NimbyLocked proc.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HostInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddComment': grpc.unary_unary_rpc_method_handler(
                    servicer.AddComment,
                    request_deserializer=host__pb2.HostAddCommentRequest.FromString,
                    response_serializer=host__pb2.HostAddCommentResponse.SerializeToString,
            ),
            'AddTags': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTags,
                    request_deserializer=host__pb2.HostAddTagsRequest.FromString,
                    response_serializer=host__pb2.HostAddTagsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=host__pb2.HostDeleteRequest.FromString,
                    response_serializer=host__pb2.HostDeleteResponse.SerializeToString,
            ),
            'FindHost': grpc.unary_unary_rpc_method_handler(
                    servicer.FindHost,
                    request_deserializer=host__pb2.HostFindHostRequest.FromString,
                    response_serializer=host__pb2.HostFindHostResponse.SerializeToString,
            ),
            'GetComments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComments,
                    request_deserializer=host__pb2.HostGetCommentsRequest.FromString,
                    response_serializer=host__pb2.HostGetCommentsResponse.SerializeToString,
            ),
            'GetDeed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeed,
                    request_deserializer=host__pb2.HostGetDeedRequest.FromString,
                    response_serializer=host__pb2.HostGetDeedResponse.SerializeToString,
            ),
            'GetHost': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHost,
                    request_deserializer=host__pb2.HostGetHostRequest.FromString,
                    response_serializer=host__pb2.HostGetHostResponse.SerializeToString,
            ),
            'GetHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHosts,
                    request_deserializer=host__pb2.HostGetHostsRequest.FromString,
                    response_serializer=host__pb2.HostGetHostsResponse.SerializeToString,
            ),
            'GetHostWhiteboard': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHostWhiteboard,
                    request_deserializer=host__pb2.HostGetHostWhiteboardRequest.FromString,
                    response_serializer=host__pb2.HostGetHostWhiteboardResponse.SerializeToString,
            ),
            'GetOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOwner,
                    request_deserializer=host__pb2.HostGetOwnerRequest.FromString,
                    response_serializer=host__pb2.HostGetOwnerResponse.SerializeToString,
            ),
            'GetProcs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProcs,
                    request_deserializer=host__pb2.HostGetProcsRequest.FromString,
                    response_serializer=host__pb2.HostGetProcsResponse.SerializeToString,
            ),
            'GetRenderPartitions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRenderPartitions,
                    request_deserializer=host__pb2.HostGetRenderPartitionsRequest.FromString,
                    response_serializer=host__pb2.HostGetRenderPartitionsResponse.SerializeToString,
            ),
            'Lock': grpc.unary_unary_rpc_method_handler(
                    servicer.Lock,
                    request_deserializer=host__pb2.HostLockRequest.FromString,
                    response_serializer=host__pb2.HostLockResponse.SerializeToString,
            ),
            'Reboot': grpc.unary_unary_rpc_method_handler(
                    servicer.Reboot,
                    request_deserializer=host__pb2.HostRebootRequest.FromString,
                    response_serializer=host__pb2.HostRebootResponse.SerializeToString,
            ),
            'RebootWhenIdle': grpc.unary_unary_rpc_method_handler(
                    servicer.RebootWhenIdle,
                    request_deserializer=host__pb2.HostRebootWhenIdleRequest.FromString,
                    response_serializer=host__pb2.HostRebootWhenIdleResponse.SerializeToString,
            ),
            'RedirectToJob': grpc.unary_unary_rpc_method_handler(
                    servicer.RedirectToJob,
                    request_deserializer=host__pb2.HostRedirectToJobRequest.FromString,
                    response_serializer=host__pb2.HostRedirectToJobResponse.SerializeToString,
            ),
            'RemoveTags': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveTags,
                    request_deserializer=host__pb2.HostRemoveTagsRequest.FromString,
                    response_serializer=host__pb2.HostRemoveTagsResponse.SerializeToString,
            ),
            'RenameTag': grpc.unary_unary_rpc_method_handler(
                    servicer.RenameTag,
                    request_deserializer=host__pb2.HostRenameTagRequest.FromString,
                    response_serializer=host__pb2.HostRenameTagResponse.SerializeToString,
            ),
            'SetAllocation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAllocation,
                    request_deserializer=host__pb2.HostSetAllocationRequest.FromString,
                    response_serializer=host__pb2.HostSetAllocationResponse.SerializeToString,
            ),
            'SetHardwareState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetHardwareState,
                    request_deserializer=host__pb2.HostSetHardwareStateRequest.FromString,
                    response_serializer=host__pb2.HostSetHardwareStateResponse.SerializeToString,
            ),
            'SetOs': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOs,
                    request_deserializer=host__pb2.HostSetOsRequest.FromString,
                    response_serializer=host__pb2.HostSetOsResponse.SerializeToString,
            ),
            'SetThreadMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetThreadMode,
                    request_deserializer=host__pb2.HostSetThreadModeRequest.FromString,
                    response_serializer=host__pb2.HostSetThreadModeResponse.SerializeToString,
            ),
            'Unlock': grpc.unary_unary_rpc_method_handler(
                    servicer.Unlock,
                    request_deserializer=host__pb2.HostUnlockRequest.FromString,
                    response_serializer=host__pb2.HostUnlockResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'host.HostInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HostInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddComment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/AddComment',
            host__pb2.HostAddCommentRequest.SerializeToString,
            host__pb2.HostAddCommentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/AddTags',
            host__pb2.HostAddTagsRequest.SerializeToString,
            host__pb2.HostAddTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/Delete',
            host__pb2.HostDeleteRequest.SerializeToString,
            host__pb2.HostDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindHost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/FindHost',
            host__pb2.HostFindHostRequest.SerializeToString,
            host__pb2.HostFindHostResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetComments',
            host__pb2.HostGetCommentsRequest.SerializeToString,
            host__pb2.HostGetCommentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetDeed',
            host__pb2.HostGetDeedRequest.SerializeToString,
            host__pb2.HostGetDeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetHost',
            host__pb2.HostGetHostRequest.SerializeToString,
            host__pb2.HostGetHostResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetHosts',
            host__pb2.HostGetHostsRequest.SerializeToString,
            host__pb2.HostGetHostsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHostWhiteboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetHostWhiteboard',
            host__pb2.HostGetHostWhiteboardRequest.SerializeToString,
            host__pb2.HostGetHostWhiteboardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetOwner',
            host__pb2.HostGetOwnerRequest.SerializeToString,
            host__pb2.HostGetOwnerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProcs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetProcs',
            host__pb2.HostGetProcsRequest.SerializeToString,
            host__pb2.HostGetProcsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRenderPartitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/GetRenderPartitions',
            host__pb2.HostGetRenderPartitionsRequest.SerializeToString,
            host__pb2.HostGetRenderPartitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Lock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/Lock',
            host__pb2.HostLockRequest.SerializeToString,
            host__pb2.HostLockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reboot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/Reboot',
            host__pb2.HostRebootRequest.SerializeToString,
            host__pb2.HostRebootResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RebootWhenIdle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/RebootWhenIdle',
            host__pb2.HostRebootWhenIdleRequest.SerializeToString,
            host__pb2.HostRebootWhenIdleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RedirectToJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/RedirectToJob',
            host__pb2.HostRedirectToJobRequest.SerializeToString,
            host__pb2.HostRedirectToJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/RemoveTags',
            host__pb2.HostRemoveTagsRequest.SerializeToString,
            host__pb2.HostRemoveTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RenameTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/RenameTag',
            host__pb2.HostRenameTagRequest.SerializeToString,
            host__pb2.HostRenameTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAllocation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/SetAllocation',
            host__pb2.HostSetAllocationRequest.SerializeToString,
            host__pb2.HostSetAllocationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetHardwareState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/SetHardwareState',
            host__pb2.HostSetHardwareStateRequest.SerializeToString,
            host__pb2.HostSetHardwareStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetOs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/SetOs',
            host__pb2.HostSetOsRequest.SerializeToString,
            host__pb2.HostSetOsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetThreadMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/SetThreadMode',
            host__pb2.HostSetThreadModeRequest.SerializeToString,
            host__pb2.HostSetThreadModeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.HostInterface/Unlock',
            host__pb2.HostUnlockRequest.SerializeToString,
            host__pb2.HostUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class OwnerInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Delete = channel.unary_unary(
                '/host.OwnerInterface/Delete',
                request_serializer=host__pb2.OwnerDeleteRequest.SerializeToString,
                response_deserializer=host__pb2.OwnerDeleteResponse.FromString,
                )
        self.GetDeeds = channel.unary_unary(
                '/host.OwnerInterface/GetDeeds',
                request_serializer=host__pb2.OwnerGetDeedsRequest.SerializeToString,
                response_deserializer=host__pb2.OwnerGetDeedsResponse.FromString,
                )
        self.GetHosts = channel.unary_unary(
                '/host.OwnerInterface/GetHosts',
                request_serializer=host__pb2.OwnerGetHostsRequest.SerializeToString,
                response_deserializer=host__pb2.OwnerGetHostsResponse.FromString,
                )
        self.GetOwner = channel.unary_unary(
                '/host.OwnerInterface/GetOwner',
                request_serializer=host__pb2.OwnerGetOwnerRequest.SerializeToString,
                response_deserializer=host__pb2.OwnerGetOwnerResponse.FromString,
                )
        self.SetShow = channel.unary_unary(
                '/host.OwnerInterface/SetShow',
                request_serializer=host__pb2.OwnerSetShowRequest.SerializeToString,
                response_deserializer=host__pb2.OwnerSetShowResponse.FromString,
                )
        self.TakeOwnership = channel.unary_unary(
                '/host.OwnerInterface/TakeOwnership',
                request_serializer=host__pb2.OwnerTakeOwnershipRequest.SerializeToString,
                response_deserializer=host__pb2.OwnerTakeOwnershipResponse.FromString,
                )


class OwnerInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Delete(self, request, context):
        """Deletes the owner record.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeeds(self, request, context):
        """Get a list of all deeds this owner has.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHosts(self, request, context):
        """Get a list of all hosts this owner is responsible for.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOwner(self, request, context):
        """Return an Owner record by name, id, or email.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetShow(self, request, context):
        """Sets the owners show.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TakeOwnership(self, request, context):
        """Set the hosts new owner settings.  Any host may have an owner, not just desktops.  This allows direct control of
        the cores.  By default hosts have no owner settings.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OwnerInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=host__pb2.OwnerDeleteRequest.FromString,
                    response_serializer=host__pb2.OwnerDeleteResponse.SerializeToString,
            ),
            'GetDeeds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeeds,
                    request_deserializer=host__pb2.OwnerGetDeedsRequest.FromString,
                    response_serializer=host__pb2.OwnerGetDeedsResponse.SerializeToString,
            ),
            'GetHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHosts,
                    request_deserializer=host__pb2.OwnerGetHostsRequest.FromString,
                    response_serializer=host__pb2.OwnerGetHostsResponse.SerializeToString,
            ),
            'GetOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOwner,
                    request_deserializer=host__pb2.OwnerGetOwnerRequest.FromString,
                    response_serializer=host__pb2.OwnerGetOwnerResponse.SerializeToString,
            ),
            'SetShow': grpc.unary_unary_rpc_method_handler(
                    servicer.SetShow,
                    request_deserializer=host__pb2.OwnerSetShowRequest.FromString,
                    response_serializer=host__pb2.OwnerSetShowResponse.SerializeToString,
            ),
            'TakeOwnership': grpc.unary_unary_rpc_method_handler(
                    servicer.TakeOwnership,
                    request_deserializer=host__pb2.OwnerTakeOwnershipRequest.FromString,
                    response_serializer=host__pb2.OwnerTakeOwnershipResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'host.OwnerInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OwnerInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.OwnerInterface/Delete',
            host__pb2.OwnerDeleteRequest.SerializeToString,
            host__pb2.OwnerDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeeds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.OwnerInterface/GetDeeds',
            host__pb2.OwnerGetDeedsRequest.SerializeToString,
            host__pb2.OwnerGetDeedsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.OwnerInterface/GetHosts',
            host__pb2.OwnerGetHostsRequest.SerializeToString,
            host__pb2.OwnerGetHostsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.OwnerInterface/GetOwner',
            host__pb2.OwnerGetOwnerRequest.SerializeToString,
            host__pb2.OwnerGetOwnerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetShow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.OwnerInterface/SetShow',
            host__pb2.OwnerSetShowRequest.SerializeToString,
            host__pb2.OwnerSetShowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TakeOwnership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.OwnerInterface/TakeOwnership',
            host__pb2.OwnerTakeOwnershipRequest.SerializeToString,
            host__pb2.OwnerTakeOwnershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ProcInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClearRedirect = channel.unary_unary(
                '/host.ProcInterface/ClearRedirect',
                request_serializer=host__pb2.ProcClearRedirectRequest.SerializeToString,
                response_deserializer=host__pb2.ProcClearRedirectResponse.FromString,
                )
        self.GetFrame = channel.unary_unary(
                '/host.ProcInterface/GetFrame',
                request_serializer=host__pb2.ProcGetFrameRequest.SerializeToString,
                response_deserializer=host__pb2.ProcGetFrameResponse.FromString,
                )
        self.GetHost = channel.unary_unary(
                '/host.ProcInterface/GetHost',
                request_serializer=host__pb2.ProcGetHostRequest.SerializeToString,
                response_deserializer=host__pb2.ProcGetHostResponse.FromString,
                )
        self.GetJob = channel.unary_unary(
                '/host.ProcInterface/GetJob',
                request_serializer=host__pb2.ProcGetJobRequest.SerializeToString,
                response_deserializer=host__pb2.ProcGetJobResponse.FromString,
                )
        self.GetLayer = channel.unary_unary(
                '/host.ProcInterface/GetLayer',
                request_serializer=host__pb2.ProcGetLayerRequest.SerializeToString,
                response_deserializer=host__pb2.ProcGetLayerResponse.FromString,
                )
        self.GetProcs = channel.unary_unary(
                '/host.ProcInterface/GetProcs',
                request_serializer=host__pb2.ProcGetProcsRequest.SerializeToString,
                response_deserializer=host__pb2.ProcGetProcsResponse.FromString,
                )
        self.Kill = channel.unary_unary(
                '/host.ProcInterface/Kill',
                request_serializer=host__pb2.ProcKillRequest.SerializeToString,
                response_deserializer=host__pb2.ProcKillResponse.FromString,
                )
        self.RedirectToGroup = channel.unary_unary(
                '/host.ProcInterface/RedirectToGroup',
                request_serializer=host__pb2.ProcRedirectToGroupRequest.SerializeToString,
                response_deserializer=host__pb2.ProcRedirectToGroupResponse.FromString,
                )
        self.RedirectToJob = channel.unary_unary(
                '/host.ProcInterface/RedirectToJob',
                request_serializer=host__pb2.ProcRedirectToJobRequest.SerializeToString,
                response_deserializer=host__pb2.ProcRedirectToJobResponse.FromString,
                )
        self.Unbook = channel.unary_unary(
                '/host.ProcInterface/Unbook',
                request_serializer=host__pb2.ProcUnbookRequest.SerializeToString,
                response_deserializer=host__pb2.ProcUnbookResponse.FromString,
                )
        self.UnbookProcs = channel.unary_unary(
                '/host.ProcInterface/UnbookProcs',
                request_serializer=host__pb2.ProcUnbookProcsRequest.SerializeToString,
                response_deserializer=host__pb2.ProcUnbookProcsResponse.FromString,
                )
        self.UnbookToGroup = channel.unary_unary(
                '/host.ProcInterface/UnbookToGroup',
                request_serializer=host__pb2.ProcUnbookToGroupRequest.SerializeToString,
                response_deserializer=host__pb2.ProcUnbookToGroupResponse.FromString,
                )
        self.UnbookToJob = channel.unary_unary(
                '/host.ProcInterface/UnbookToJob',
                request_serializer=host__pb2.ProcUnbookToJobRequest.SerializeToString,
                response_deserializer=host__pb2.ProcUnbookToJobResponse.FromString,
                )


class ProcInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ClearRedirect(self, request, context):
        """Clears the redirect off of the proc so it dispatches naturally.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrame(self, request, context):
        """Returns the [Frame] running on the [Proc]
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHost(self, request, context):
        """Returns the [Host] this [Proc] was allocated from.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJob(self, request, context):
        """Returns the [Job] the [Proc] has been assigned to.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLayer(self, request, context):
        """Returns the [Layer] the [Proc] has been assigned to.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProcs(self, request, context):
        """Return a list of procs matching the search
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Kill(self, request, context):
        """Sends a kill signal to the running process.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RedirectToGroup(self, request, context):
        """Unbooks and redriects the proc to the specified group.  Optionally kills the proc immediately.  Will overwrite an
        existing redirect. Return true if the redirect was a success. The redirect would fail in the event that the
        specified group does not have a suitable frame for the proc.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RedirectToJob(self, request, context):
        """Unbooks and redriects the proc to the specified job.  Optionally kills the proc immediately.  Will overwrite an
        existing redirect. Return true if the redirect was a success. The redirect would fail in the event th
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unbook(self, request, context):
        """Unbooks this [Proc].  Unbooking means the [Proc] will automatically seek out a new [Job] when the current
        [Frame] is complete.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbookProcs(self, request, context):
        """Unbooks procs that match the ProcSearchCriteria.  This request can span jobs, shows, allocations, hosts etc.
        Set kill to true if the running frames should immediately be killed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbookToGroup(self, request, context):
        """Unbooks procs that match the ProcSearchCriteria and books them on the specified group, assuming the group has
        layers that can take the procs. If the kill boolean is set to true, the operation happens immediately. If false,
        the proc will move after it finishes its current frame.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbookToJob(self, request, context):
        """Unbooks procs that match the ProcSearchCriteria and books them on the specified list of jobs, assuming those jobs
        have layers that can take the procs. If the kill boolean is set to true, the operation happens immediately. If
        false, the proc will move after it finishes its current frame.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProcInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ClearRedirect': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearRedirect,
                    request_deserializer=host__pb2.ProcClearRedirectRequest.FromString,
                    response_serializer=host__pb2.ProcClearRedirectResponse.SerializeToString,
            ),
            'GetFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrame,
                    request_deserializer=host__pb2.ProcGetFrameRequest.FromString,
                    response_serializer=host__pb2.ProcGetFrameResponse.SerializeToString,
            ),
            'GetHost': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHost,
                    request_deserializer=host__pb2.ProcGetHostRequest.FromString,
                    response_serializer=host__pb2.ProcGetHostResponse.SerializeToString,
            ),
            'GetJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJob,
                    request_deserializer=host__pb2.ProcGetJobRequest.FromString,
                    response_serializer=host__pb2.ProcGetJobResponse.SerializeToString,
            ),
            'GetLayer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLayer,
                    request_deserializer=host__pb2.ProcGetLayerRequest.FromString,
                    response_serializer=host__pb2.ProcGetLayerResponse.SerializeToString,
            ),
            'GetProcs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProcs,
                    request_deserializer=host__pb2.ProcGetProcsRequest.FromString,
                    response_serializer=host__pb2.ProcGetProcsResponse.SerializeToString,
            ),
            'Kill': grpc.unary_unary_rpc_method_handler(
                    servicer.Kill,
                    request_deserializer=host__pb2.ProcKillRequest.FromString,
                    response_serializer=host__pb2.ProcKillResponse.SerializeToString,
            ),
            'RedirectToGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.RedirectToGroup,
                    request_deserializer=host__pb2.ProcRedirectToGroupRequest.FromString,
                    response_serializer=host__pb2.ProcRedirectToGroupResponse.SerializeToString,
            ),
            'RedirectToJob': grpc.unary_unary_rpc_method_handler(
                    servicer.RedirectToJob,
                    request_deserializer=host__pb2.ProcRedirectToJobRequest.FromString,
                    response_serializer=host__pb2.ProcRedirectToJobResponse.SerializeToString,
            ),
            'Unbook': grpc.unary_unary_rpc_method_handler(
                    servicer.Unbook,
                    request_deserializer=host__pb2.ProcUnbookRequest.FromString,
                    response_serializer=host__pb2.ProcUnbookResponse.SerializeToString,
            ),
            'UnbookProcs': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbookProcs,
                    request_deserializer=host__pb2.ProcUnbookProcsRequest.FromString,
                    response_serializer=host__pb2.ProcUnbookProcsResponse.SerializeToString,
            ),
            'UnbookToGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbookToGroup,
                    request_deserializer=host__pb2.ProcUnbookToGroupRequest.FromString,
                    response_serializer=host__pb2.ProcUnbookToGroupResponse.SerializeToString,
            ),
            'UnbookToJob': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbookToJob,
                    request_deserializer=host__pb2.ProcUnbookToJobRequest.FromString,
                    response_serializer=host__pb2.ProcUnbookToJobResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'host.ProcInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProcInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ClearRedirect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/ClearRedirect',
            host__pb2.ProcClearRedirectRequest.SerializeToString,
            host__pb2.ProcClearRedirectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/GetFrame',
            host__pb2.ProcGetFrameRequest.SerializeToString,
            host__pb2.ProcGetFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/GetHost',
            host__pb2.ProcGetHostRequest.SerializeToString,
            host__pb2.ProcGetHostResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/GetJob',
            host__pb2.ProcGetJobRequest.SerializeToString,
            host__pb2.ProcGetJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLayer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/GetLayer',
            host__pb2.ProcGetLayerRequest.SerializeToString,
            host__pb2.ProcGetLayerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProcs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/GetProcs',
            host__pb2.ProcGetProcsRequest.SerializeToString,
            host__pb2.ProcGetProcsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Kill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/Kill',
            host__pb2.ProcKillRequest.SerializeToString,
            host__pb2.ProcKillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RedirectToGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/RedirectToGroup',
            host__pb2.ProcRedirectToGroupRequest.SerializeToString,
            host__pb2.ProcRedirectToGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RedirectToJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/RedirectToJob',
            host__pb2.ProcRedirectToJobRequest.SerializeToString,
            host__pb2.ProcRedirectToJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unbook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/Unbook',
            host__pb2.ProcUnbookRequest.SerializeToString,
            host__pb2.ProcUnbookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbookProcs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/UnbookProcs',
            host__pb2.ProcUnbookProcsRequest.SerializeToString,
            host__pb2.ProcUnbookProcsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbookToGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/UnbookToGroup',
            host__pb2.ProcUnbookToGroupRequest.SerializeToString,
            host__pb2.ProcUnbookToGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbookToJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/host.ProcInterface/UnbookToJob',
            host__pb2.ProcUnbookToJobRequest.SerializeToString,
            host__pb2.ProcUnbookToJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x07service\"\xfe\x01\n\x07Service\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nthreadable\x18\x03 \x01(\x08\x12\x11\n\tmin_cores\x18\x04 \x01(\x05\x12\x11\n\tmax_cores\x18\x05 \x01(\x05\x12\x12\n\nmin_memory\x18\x06 \x01(\x03\x12\x16\n\x0emin_gpu_memory\x18\x07 \x01(\x03\x12\x0c\n\x04tags\x18\x08 \x03(\t\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\x13\n\x0btimeout_llu\x18\n \x01(\x05\x12\x10\n\x08min_gpus\x18\x0b \x01(\x05\x12\x10\n\x08max_gpus\x18\x0c \x01(\x05\x12\x1b\n\x13min_memory_increase\x18\r \x01(\x05\"0\n\nServiceSeq\x12\"\n\x08services\x18\x01 \x03(\x0b\x32\x10.service.Service\"=\n\x0fServiceOverride\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1e\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x10.service.Service\"I\n\x12ServiceOverrideSeq\x12\x33\n\x11service_overrides\x18\x01 \x03(\x0b\x32\x18.service.ServiceOverride\"=\n\x1bServiceCreateServiceRequest\x12\x1e\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x10.service.Service\"A\n\x1cServiceCreateServiceResponse\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"9\n\x14ServiceDeleteRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x17\n\x15ServiceDeleteResponse\"\"\n ServiceGetDefaultServicesRequest\"J\n!ServiceGetDefaultServicesResponse\x12%\n\x08services\x18\x01 \x01(\x0b\x32\x13.service.ServiceSeq\"(\n\x18ServiceGetServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\">\n\x19ServiceGetServiceResponse\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"9\n\x14ServiceUpdateRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x17\n\x15ServiceUpdateResponse\"A\n\x1cServiceOverrideDeleteRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x1f\n\x1dServiceOverrideDeleteResponse\"A\n\x1cServiceOverrideUpdateRequest\x12!\n\x07service\x18\x01 \x01(\x0b\x32\x10.service.Service\"\x1f\n\x1dServiceOverrideUpdateResponse2\xc4\x03\n\x10ServiceInterface\x12\\\n\rCreateService\x12$.service.ServiceCreateServiceRequest\x1a%.service.ServiceCreateServiceResponse\x12G\n\x06\x44\x65lete\x12\x1d.service.ServiceDeleteRequest\x1a\x1e.service.ServiceDeleteResponse\x12k\n\x12GetDefaultServices\x12).service.ServiceGetDefaultServicesRequest\x1a*.service.ServiceGetDefaultServicesResponse\x12S\n\nGetService\x12!.service.ServiceGetServiceRequest\x1a\".service.ServiceGetServiceResponse\x12G\n\x06Update\x12\x1d.service.ServiceUpdateRequest\x1a\x1e.service.ServiceUpdateResponse2\xcc\x01\n\x18ServiceOverrideInterface\x12W\n\x06\x44\x65lete\x12%.service.ServiceOverrideDeleteRequest\x1a&.service.ServiceOverrideDeleteResponse\x12W\n\x06Update\x12%.service.ServiceOverrideUpdateRequest\x1a&.service.ServiceOverrideUpdateResponseB=\n!com.imageworks.spcue.grpc.serviceP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.imageworks.spcue.grpc.serviceP\001Z\026opencue_gateway/gen/go'
  _globals['_SERVICE']._serialized_start=27
  _globals['_SERVICE']._serialized_end=281
  _globals['_SERVICESEQ']._serialized_start=283
  _globals['_SERVICESEQ']._serialized_end=331
  _globals['_SERVICEOVERRIDE']._serialized_start=333
  _globals['_SERVICEOVERRIDE']._serialized_end=394
  _globals['_SERVICEOVERRIDESEQ']._serialized_start=396
  _globals['_SERVICEOVERRIDESEQ']._serialized_end=469
  _globals['_SERVICECREATESERVICEREQUEST']._serialized_start=471
  _globals['_SERVICECREATESERVICEREQUEST']._serialized_end=532
  _globals['_SERVICECREATESERVICERESPONSE']._serialized_start=534
  _globals['_SERVICECREATESERVICERESPONSE']._serialized_end=599
  _globals['_SERVICEDELETEREQUEST']._serialized_start=601
  _globals['_SERVICEDELETEREQUEST']._serialized_end=658
  _globals['_SERVICEDELETERESPONSE']._serialized_start=660
  _globals['_SERVICEDELETERESPONSE']._serialized_end=683
  _globals['_SERVICEGETDEFAULTSERVICESREQUEST']._serialized_start=685
  _globals['_SERVICEGETDEFAULTSERVICESREQUEST']._serialized_end=719
  _globals['_SERVICEGETDEFAULTSERVICESRESPONSE']._serialized_start=721
  _globals['_SERVICEGETDEFAULTSERVICESRESPONSE']._serialized_end=795
  _globals['_SERVICEGETSERVICEREQUEST']._serialized_start=797
  _globals['_SERVICEGETSERVICEREQUEST']._serialized_end=837
  _globals['_SERVICEGETSERVICERESPONSE']._serialized_start=839
  _globals['_SERVICEGETSERVICERESPONSE']._serialized_end=901
  _globals['_SERVICEUPDATEREQUEST']._serialized_start=903
  _globals['_SERVICEUPDATEREQUEST']._serialized_end=960
  _globals['_SERVICEUPDATERESPONSE']._serialized_start=962
  _globals['_SERVICEUPDATERESPONSE']._serialized_end=985
  _globals['_SERVICEOVERRIDEDELETEREQUEST']._serialized_start=987
  _globals['_SERVICEOVERRIDEDELETEREQUEST']._serialized_end=1052
  _globals['_SERVICEOVERRIDEDELETERESPONSE']._serialized_start=1054
  _globals['_SERVICEOVERRIDEDELETERESPONSE']._serialized_end=1085
  _globals['_SERVICEOVERRIDEUPDATEREQUEST']._serialized_start=1087
  _globals['_SERVICEOVERRIDEUPDATEREQUEST']._serialized_end=1152
  _globals['_SERVICEOVERRIDEUPDATERESPONSE']._serialized_start=1154
  _globals['_SERVICEOVERRIDEUPDATERESPONSE']._serialized_end=1185
  _globals['_SERVICEINTERFACE']._serialized_start=1188
  _globals['_SERVICEINTERFACE']._serialized_end=1640
  _globals['_SERVICEOVERRIDEINTERFACE']._serialized_start=1643
  _globals['_SERVICEOVERRIDEINTERFACE']._serialized_end=1847
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import subscription_pb2 as subscription__pb2


class SubscriptionInterfaceStub(object):
    """Subscriptions
    A subscription is what a show sets up when they want to use hosts in
    an allocation.

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Delete = channel.unary_unary(
                '/subscription.SubscriptionInterface/Delete',
                request_serializer=subscription__pb2.SubscriptionDeleteRequest.SerializeToString,
                response_deserializer=subscription__pb2.SubscriptionDeleteResponse.FromString,
                )
        self.Find = channel.unary_unary(
                '/subscription.SubscriptionInterface/Find',
                request_serializer=subscription__pb2.SubscriptionFindRequest.SerializeToString,
                response_deserializer=subscription__pb2.SubscriptionFindResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/subscription.SubscriptionInterface/Get',
                request_serializer=subscription__pb2.SubscriptionGetRequest.SerializeToString,
                response_deserializer=subscription__pb2.SubscriptionGetResponse.FromString,
                )
        self.SetBurst = channel.unary_unary(
                '/subscription.SubscriptionInterface/SetBurst',
                request_serializer=subscription__pb2.SubscriptionSetBurstRequest.SerializeToString,
                response_deserializer=subscription__pb2.SubscriptionSetBurstResponse.FromString,
                )
        self.SetSize = channel.unary_unary(
                '/subscription.SubscriptionInterface/SetSize',
                request_serializer=subscription__pb2.SubscriptionSetSizeRequest.SerializeToString,
                response_deserializer=subscription__pb2.SubscriptionSetSizeResponse.FromString,
                )


class SubscriptionInterfaceServicer(object):
    """Subscriptions
    A subscription is what a show sets up when they want to use hosts in
    an allocation.

    -------- Services --------]

    """

    def Delete(self, request, context):
        """Delete a subscription
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Find(self, request, context):
        """Find a subscription by name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Locate a subscription by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBurst(self, request, context):
        """Set the burst size of a subscription
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSize(self, request, context):
        """Set the size of a subscription
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SubscriptionInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=subscription__pb2.SubscriptionDeleteRequest.FromString,
                    response_serializer=subscription__pb2.SubscriptionDeleteResponse.SerializeToString,
            ),
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=subscription__pb2.SubscriptionFindRequest.FromString,
                    response_serializer=subscription__pb2.SubscriptionFindResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=subscription__pb2.SubscriptionGetRequest.FromString,
                    response_serializer=subscription__pb2.SubscriptionGetResponse.SerializeToString,
            ),
            'SetBurst': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBurst,
                    request_deserializer=subscription__pb2.SubscriptionSetBurstRequest.FromString,
                    response_serializer=subscription__pb2.SubscriptionSetBurstResponse.SerializeToString,
            ),
            'SetSize': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSize,
                    request_deserializer=subscription__pb2.SubscriptionSetSizeRequest.FromString,
                    response_serializer=subscription__pb2.SubscriptionSetSizeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'subscription.SubscriptionInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SubscriptionInterface(object):
    """Subscriptions
    A subscription is what a show sets up when they want to use hosts in
    an allocation.

    -------- Services --------]

    """

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/subscription.SubscriptionInterface/Delete',
            subscription__pb2.SubscriptionDeleteRequest.SerializeToString,
            subscription__pb2.SubscriptionDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/subscription.SubscriptionInterface/Find',
            subscription__pb2.SubscriptionFindRequest.SerializeToString,
            subscription__pb2.SubscriptionFindResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/subscription.SubscriptionInterface/Get',
            subscription__pb2.SubscriptionGetRequest.SerializeToString,
            subscription__pb2.SubscriptionGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetBurst(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/subscription.SubscriptionInterface/SetBurst',
            subscription__pb2.SubscriptionSetBurstRequest.SerializeToString,
            subscription__pb2.SubscriptionSetBurstResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/subscription.SubscriptionInterface/SetSize',
            subscription__pb2.SubscriptionSetSizeRequest.SerializeToString,
            subscription__pb2.SubscriptionSetSizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)